==> haskell-glib-0.13.4.1-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: glib
version: 0.13.4.1
id: glib-0.13.4.1-Krxwx6yZMu0HfAhl5ALpGz
key: glib-0.13.4.1-Krxwx6yZMu0HfAhl5ALpGz
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
indefinite: False
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils
abi: c92533528b5e726dbf7d65112213f140
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/glib-0.13.4.1
library-dirs: /usr/lib/ghc-8.2.1/site-local/glib-0.13.4.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.1/glib-0.13.4.1
hs-libraries: HSglib-0.13.4.1-Krxwx6yZMu0HfAhl5ALpGz
extra-libraries:
    gobject-2.0 glib-2.0
include-dirs: /usr/include/glib-2.0 /usr/lib/glib-2.0/include
depends:
    base-4.10.0.0 utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m
    bytestring-0.10.8.2 text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz
    containers-0.5.10.2
abi-depends: base-4.10.0.0=32d562aa6d04d35ac79a0f49c17325ff
             utf8-string-1.0.1.1-CvukXmdyLbdJ7d5kadRf8m=8d643a529d99a952051170bc6a18d0f2
             bytestring-0.10.8.2=4f0c9618a8f04261f970de9708e01603
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=42480b67fee41ad692110e11eaac57c4
             containers-0.5.10.2=e086202b65ca66a107fcba9d846fc3e0
haddock-interfaces: /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html: /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glib-0.13.5.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-glib.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: glib
version: 0.13.5.0
id: glib-0.13.5.0-BGVYE4UfPO71NUSSN3P5KJ
key: glib-0.13.5.0-BGVYE4UfPO71NUSSN3P5KJ
license: LGPL-2.1
copyright: (c) 2001-2010 The Gtk2Hs Team
maintainer: gtk2hs-users@lists.sourceforge.net
stability: stable
homepage: http://projects.haskell.org/gtk2hs/
synopsis: Binding to the GLIB library for Gtk2Hs.
description:
    GLib is a collection of C data structures and utility functions
    for the GObject system, main loop implementation, for strings and
    common data structures dealing with Unicode. This package only binds
    as much functionality as required to support the packages that
    wrap libraries that are themselves based on GLib.
category: System
author: Axel Simon, Duncan Coutts
exposed: True
indefinite: False
exposed-modules:
    System.Glib System.Glib.Attributes System.Glib.FFI
    System.Glib.Flags System.Glib.GDateTime System.Glib.GError
    System.Glib.GList System.Glib.GObject System.Glib.GParameter
    System.Glib.GString System.Glib.GType System.Glib.GTypeConstants
    System.Glib.GValue System.Glib.GValueTypes System.Glib.MainLoop
    System.Glib.Properties System.Glib.Signals System.Glib.StoreValue
    System.Glib.Types System.Glib.UTFString System.Glib.Utils
abi: 6447e27b1ba09b9ca11b08f6a51195ed
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/glib-0.13.5.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/glib-0.13.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/glib-0.13.5.0
hs-libraries: HSglib-0.13.5.0-BGVYE4UfPO71NUSSN3P5KJ
extra-libraries:
    gobject-2.0 glib-2.0
include-dirs: /usr/include/glib-2.0 /usr/lib/glib-2.0/include
depends:
    base-4.10.1.0 utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO
    bytestring-0.10.8.2 text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj
    containers-0.5.10.2
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             utf8-string-1.0.1.1-7sQ7eR5H5ED7poickls5aO=4a40da384793deade7b4b9c9224acdb7
             bytestring-0.10.8.2=4b2726b654ceeff6535e698a2a1e724e
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=19cd54ed0f93cc2e72d3ff0c754f5306
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
haddock-interfaces: /usr/share/doc/haskell-glib/html/glib.haddock
haddock-html: /usr/share/doc/haskell-glib/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
